#!/usr/bin/env perl

use Acme::Boolean;
use Test::More;

plan tests => 11;

ok so correct;
ok very right;
ok very very very perfect;
ok not so wrong;
ok not very errorneous;
ok not absolutely nah;
ok undoubtedly undoubted;
ok TOTALLY UNDENIABLE;
ok NOT EXACTLY LYING;
ok REALLY REALLY TRUE;
ok not ABSOLUTELY FAKE;
